#!/usr/bin/env python
#coding=utf-8

import onelab
import math, os
import string

OL = onelab.client(__file__)

#####
NumberIter  = OL.defineNumber('Parameters/2Elmer/NumberIter', value=400)
TimeStep    = OL.defineNumber('Parameters/2Elmer/TimeStep', value=0.005)
Viscosity   = OL.defineNumber('Parameters/3Model/Viscosity', value=3.5e-3)
Elasticity  = OL.defineNumber('Parameters/3Model/Elasticity', label='Young Modulus',value=3e5)
Poisson     = OL.defineNumber('Parameters/3Model/Poisson_ratio', label= 'Poisson Ratio', value=0.45)

WallThick   = OL.defineNumber('Parameters/1Geometry/Wall_thickness', label='Wall Thickness', value=0.002)
ArtryRadius = OL.defineNumber('Parameters/1Geometry/Artery_radius', label='Artery Radius', value=0.0125)
ArtryLength = OL.defineNumber('Parameters/1Geometry/Artery_length', label='Artery Length', value=0.4)

Frequency   = OL.defineNumber('Parameters/Ejection/Frequency', label='Frequency',value=70)
Vol_ej      = OL.defineNumber('Parameters/Ejection/Volume_Ejectionnel', label='Volume Ejectionnel [ml]',value=70)
PulseType   = OL.defineNumber('Parameters/Ejection/1Pulse_type', value = 1, label = 'Pulse type', labels = {1:'Sigmoid',2:'Linear',3:'Ten pulses'})

ArteryType  = OL.defineNumber('Parameters/1Geometry/4ArteryType', value=1,
                              label='Artery type', labels={1:'Normal (Straight)',
                                                           2:'Stenose',
                                                            3:'Atherom'})

olSTL = OL.defineNumber('Parameters/1Geometry/5Stenose_length',
                        label='Stenose Length',
                        value=0.1, attributes={'Highlight':'LightBlue'})
olSTW = OL.defineNumber('Parameters/1Geometry/5Stenose_width',
                        label='Stenose width',
                        value=0.005, attributes={'Highlight':'LightBlue'})
olSTC = OL.defineNumber('Parameters/1Geometry/5Stenose_center',
                        label='Stenose center', value=ArtryLength/2,
                        attributes={'Highlight':'LightBlue'})
olATL = OL.defineNumber('Parameters/1Geometry/5Circle_length',
                        label='Atheroma Length', value=0.01,
                        attributes={'Highlight':'LightGreen'})
olATW = OL.defineNumber('Parameters/1Geometry/5Circle_width',
                        label='Atheroma Length', value=0.005,
                         attributes={'Highlight':'LightGreen'})
olATW = OL.defineNumber('Parameters/1Geometry/5Circle_center',
                        label='Atheroma Length', value=0.1,
                         attributes={'Highlight':'LightGreen'})

if ArteryType == 1 :
    OL.setNumber('Parameters/1Geometry/4ArteryType',
                 attributes={'Highlight':''})
    OL.setNumber('Parameters/1Geometry/5Circle_center', visible=0)
    OL.setNumber('Parameters/1Geometry/5Circle_length', visible=0)
    OL.setNumber('Parameters/1Geometry/5Circle_width', visible=0)
    
    OL.setNumber('Parameters/1Geometry/5Stenose_center', visible=0)
    OL.setNumber('Parameters/1Geometry/5Stenose_length', visible=0)
    OL.setNumber('Parameters/1Geometry/5Stenose_width', visible=0)

elif ArteryType == 2 :
    OL.setNumber('Parameters/1Geometry/4ArteryType',
                 attributes={'Highlight':'LightBlue'})
    OL.setNumber('Parameters/1Geometry/5Stenose_length', visible=1)
    OL.setNumber('Parameters/1Geometry/5Stenose_width',  visible=1)
    OL.setNumber('Parameters/1Geometry/5Stenose_center', visible=1)

    OL.setNumber('Parameters/1Geometry/5Circle_length', visible=0)
    OL.setNumber('Parameters/1Geometry/5Circle_width',  visible=0)
    OL.setNumber('Parameters/1Geometry/5Circle_center', visible=0)

elif ArteryType == 3 :
    OL.setNumber('Parameters/1Geometry/4ArteryType',
                  attributes={'Highlight':'LightGreen'})
    OL.setNumber('Parameters/1Geometry/5Stenose_length', visible=0)
    OL.setNumber('Parameters/1Geometry/5Stenose_width',  visible=0)
    OL.setNumber('Parameters/1Geometry/5Stenose_center', visible=0)

    OL.setNumber('Parameters/1Geometry/5Circle_length', visible=1)
    OL.setNumber('Parameters/1Geometry/5Circle_width',  visible=1)
    OL.setNumber('Parameters/1Geometry/5Circle_center', visible=1)
####


# Display the geometry in the GUI
OL.openProject(OL.checkPath('contra.geo'))

# Check for Onelab parameters in the .geo file
# Gmsh is called with OL.run because it is native
OL.run('mesher', 'gmsh - ' +  OL.checkPath('contra.geo'),'')

OL.preProcess('elmer', OL.checkPath('case.sif.ol'))

solFiles = OL.solutionFiles('elmer', [OL.getPath('velocity.pos')] )

# Files saved when the "Archive output files automatically" option is enabled
OL.outputFiles([OL.getPath('laser.pdf')])

print solFiles

# we're done with the "check" phase
if OL.action == 'check' :
   exit(1)

if PulseType == 1:
    OL.preProcess('f90', OL.checkPath('MotionRef.f90.ol'))
    OL.call('f90','elmerf90 -o Motion MotionRef.f90')
elif PulseType == 2:
    OL.preProcess('f90', OL.checkPath('MotionLin.f90.ol'))
    OL.call('f90','elmerf90 -o Motion MotionLin.f90')
elif PulseType == 3:
    OL.preProcess('f90', OL.checkPath('MotionTen.f90.ol'))
    OL.call('f90','elmerf90 -o Motion MotionTen.f90')
    
# Mesh the geometry
OL.run('mesher', 'gmsh - ' +  OL.checkPath('contra.geo'),'-3')

# Display the mesh

OL.mergeFile(OL.checkPath('contra.msh'))

OL.call('grid', 'ElmerGrid 14 2 contra.msh -out contra', rundir=OL.wdir)

if OL.needsCompute('elmer'):
    OL.call('elmer', 'ElmerSolver case.sif', rundir=OL.wdir)
else :
    OL.copy(solFiles[0], OL.getPath('solution.pos'))

    
OL.mergeFile(OL.checkPath(solFiles[0]))

OL.mergeFile(OL.checkPath('velocity.pos'))

OL.call('postpro', 'gmsh contra.msh velocity.pos  -', rundir=OL.wdir)

## if OL.batch:
##     sys.stderr.write('%s: MAXTEMPTIME = %12.5e (%12.5e)\n' %
##                      (__file__,MAXTEMPTIME, 9.90000e-02))
